decode_integer

Function decode_integer 

pub fn decode_integer(
    buf: &[u8],
    prefix_bits: u32,
) -> Result<(u64, &[u8]), H2ParseError>
Decode an HPACK integer with prefix_bits of the first octet allocated to the integer prefix. Returns the integer and the slice immediately after it.